'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AccordionPanel = exports.AccordionHeader = exports.Accordion = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _helpers = require('./helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var containerStyle = {
  display: 'flex',
  position: 'fixed',
  left: 0,
  top: 0,
  bottom: 0
};

var Accordion = exports.Accordion = function Accordion(_ref) {
  var _ref$opened = _ref.opened;
  var opened = _ref$opened === undefined ? {} : _ref$opened;
  var _ref$onChange = _ref.onChange;
  var onChange = _ref$onChange === undefined ? function () {
    return null;
  } : _ref$onChange;
  var children = _ref.children;
  var style = _ref.style;

  var accordionStyle = _extends({}, containerStyle, style);
  var array = _react.Children.toArray(children);
  var filteredChildren = array.map(function (child) {
    switch ((0, _helpers.elementType)(child)) {
      case AccordionHeader.name:
        return (0, _react.cloneElement)(child, { _onChange: onChange });
      case AccordionPanel.name:
        if (opened[child.props.id]) {
          return child;
        } else {
          return null;
        }
      default:
        return child;
    }
  });
  return _react2.default.createElement(
    'div',
    { style: accordionStyle, className: 'accordion' },
    filteredChildren
  );
};

Accordion.propTypes = {
  opened: _react.PropTypes.objectOf(_react.PropTypes.bool),
  onChange: _react.PropTypes.func,
  children: function children(props, propName, componentName) {
    return (0, _helpers.validateAccordionChildren)(props[propName], componentName);
  }
};

var headerStyle = {
  width: '2em',
  cursor: 'pointer'
};

var AccordionHeader = exports.AccordionHeader = function AccordionHeader(_ref2) {
  var children = _ref2.children;
  var id = _ref2.id;
  var _onChange = _ref2._onChange;
  var disabled = _ref2.disabled;
  var style = _ref2.style;
  var disabledStyle = _ref2.disabledStyle;
  return _react2.default.createElement(
    'div',
    {
      className: 'header-container',
      onClick: function onClick() {
        return disabled ? null : _onChange(id);
      },
      style: _extends({}, headerStyle, disabled ? disabledStyle : style)
    },
    _react2.default.createElement(
      'div',
      {
        className: 'header',
        style: {
          display: 'inline-block',
          transform: 'translate(2em) rotate(90deg)',
          transformOrigin: '0 0 0',
          padding: '0.5em'
        }
      },
      children
    )
  );
};
AccordionHeader.propTypes = {
  id: _react.PropTypes.oneOfType([_react.PropTypes.number, _react.PropTypes.string]).isRequired,
  disabled: _react.PropTypes.bool
};

var AccordionPanel = exports.AccordionPanel = function AccordionPanel(_ref3) {
  var children = _ref3.children;
  var id = _ref3.id;
  var _ref3$onActive = _ref3.onActive;
  var onActive = _ref3$onActive === undefined ? function () {
    return null;
  } : _ref3$onActive;
  var style = _ref3.style;

  onActive(id);
  return _react2.default.createElement(
    'div',
    { style: style, className: 'panel' },
    children
  );
};
AccordionPanel.propTypes = {
  id: _react.PropTypes.oneOfType([_react.PropTypes.number, _react.PropTypes.string]).isRequired,
  onActive: _react.PropTypes.func
};