'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.elementType = exports.validateAccordionChildren = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _react = require('react');

var _FlexAccordion = require('./FlexAccordion');

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var validateAccordionChildren = exports.validateAccordionChildren = function validateAccordionChildren(children, accordionName) {
  var acceptedTypes = [_FlexAccordion.AccordionHeader.name, _FlexAccordion.AccordionPanel.name];
  var fail = areAccordionItems(children, acceptedTypes, accordionName);
  if (fail) return fail;
  return matchingAccordionItems(children, acceptedTypes, accordionName);
};

var areAccordionItems = function areAccordionItems(children, acceptedTypes, accordionName) {
  var error = void 0;
  _react.Children.forEach(children, function (child) {
    if (error) return;
    if (acceptedTypes.indexOf(elementType(child)) === -1) {
      error = new Error('Component ' + accordionName + ' only accepts children of types ' + acceptedTypes.join(', '));
    }
  });
  return error;
};

var matchingAccordionItems = function matchingAccordionItems(children, acceptedTypes, accordionName) {
  var error = void 0;
  var ids = new Map(acceptedTypes.map(function (type) {
    return [type, new Set()];
  }));
  _react.Children.forEach(children, function (child) {
    if (error) return;
    var type = elementType(child);
    var id = child.props.id;
    if (['string', 'number'].indexOf(typeof id === 'undefined' ? 'undefined' : _typeof(id)) !== -1) {
      if (ids.get(type).has(id)) {
        error = new Error('Component ' + accordionName + ' has duplicate ' + type + ' children with the same id (' + id + '). Ids must be unique.');
      } else {
        ids.get(type).add(id);
      }
    }
  });
  var idsByTypes = acceptedTypes.map(function (type) {
    return [].concat(_toConsumableArray(ids.get(type)));
  });
  if (!arraysEqual(intersectionArrays.apply(undefined, _toConsumableArray(idsByTypes)), idsByTypes[0])) {
    error = new Error('The ids of the children of component ' + accordionName + ' are not matched. There must be a component with the same id for each of the following types: ' + acceptedTypes.join(', '));
  }
  return error;
};

// Get the type of a React element
// Works with strings, React Components defined with React.createClass, as an ES6 class or as a functional component
var elementType = exports.elementType = function elementType(component) {
  if (!component.type) return typeof component === 'undefined' ? 'undefined' : _typeof(component);
  return component.type.name || component.type;
};

function intersectionArrays() {
  var n = void 0,
      len = void 0;
  var ret = [];
  var obj = {};
  var nOthers = arguments.length - 1;
  var nShortest = arguments[0].length;
  var shortest = 0;
  for (var i = 0; i <= nOthers; i++) {
    n = arguments[i].length;
    if (n < nShortest) {
      shortest = i;
      nShortest = n;
    }
  }
  for (var _i = 0; _i <= nOthers; _i++) {
    n = _i === shortest ? 0 : _i || shortest; // Read the shortest array first. Read the first array instead of the shortest
    len = arguments[n].length;
    for (var j = 0; j < len; j++) {
      var elem = arguments[n][j];
      if (obj[elem] === _i - 1) {
        if (_i === nOthers) {
          ret.push(elem);
          obj[elem] = 0;
        } else {
          obj[elem] = _i;
        }
      } else if (_i === 0) {
        obj[elem] = 0;
      }
    }
  }
  return ret;
}

function arraysEqual(a, b) {
  if (a === b) return true;
  if (a == null || b == null) return false;
  if (a.length !== b.length) return false;

  // If you don't care about the order of the elements inside
  // the array, you should sort both arrays here.

  for (var i = 0; i < a.length; ++i) {
    if (a[i] !== b[i]) return false;
  }
  return true;
}