import React, { PropTypes, Children, cloneElement } from 'react';
import { elementType, validateAccordionChildren } from './helpers';

var containerStyle = {
  display: 'flex',
  position: 'fixed',
  left: 0,
  top: 0,
  bottom: 0
};

export var Accordion = function Accordion(_ref) {
  var _ref$opened = _ref.opened;
  var opened = _ref$opened === undefined ? {} : _ref$opened;
  var _ref$onChange = _ref.onChange;
  var onChange = _ref$onChange === undefined ? function () {
    return null;
  } : _ref$onChange;
  var children = _ref.children;
  var style = _ref.style;

  var accordionStyle = babelHelpers.extends({}, containerStyle, style);
  var array = Children.toArray(children);
  var filteredChildren = array.map(function (child) {
    switch (elementType(child)) {
      case AccordionHeader.name:
        return cloneElement(child, { _onChange: onChange });
      case AccordionPanel.name:
        if (opened[child.props.id]) {
          return child;
        } else {
          return null;
        }
      default:
        return child;
    }
  });
  return React.createElement(
    'div',
    { style: accordionStyle, className: 'accordion' },
    filteredChildren
  );
};

Accordion.propTypes = {
  opened: PropTypes.objectOf(PropTypes.bool),
  onChange: PropTypes.func,
  children: function children(props, propName, componentName) {
    return validateAccordionChildren(props[propName], componentName);
  }
};

var headerStyle = {
  width: '2em',
  cursor: 'pointer'
};

export var AccordionHeader = function AccordionHeader(_ref2) {
  var children = _ref2.children;
  var id = _ref2.id;
  var _onChange = _ref2._onChange;
  var disabled = _ref2.disabled;
  var style = _ref2.style;
  var disabledStyle = _ref2.disabledStyle;
  return React.createElement(
    'div',
    {
      className: 'header-container',
      onClick: function onClick() {
        return disabled ? null : _onChange(id);
      },
      style: babelHelpers.extends({}, headerStyle, disabled ? disabledStyle : style)
    },
    React.createElement(
      'div',
      {
        className: 'header',
        style: {
          display: 'inline-block',
          transform: 'translate(2em) rotate(90deg)',
          transformOrigin: '0 0 0',
          padding: '0.5em'
        }
      },
      children
    )
  );
};
AccordionHeader.propTypes = {
  id: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired,
  disabled: PropTypes.bool
};

export var AccordionPanel = function AccordionPanel(_ref3) {
  var children = _ref3.children;
  var id = _ref3.id;
  var _ref3$onActive = _ref3.onActive;
  var onActive = _ref3$onActive === undefined ? function () {
    return null;
  } : _ref3$onActive;
  var style = _ref3.style;

  onActive(id);
  return React.createElement(
    'div',
    { style: style, className: 'panel' },
    children
  );
};
AccordionPanel.propTypes = {
  id: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired,
  onActive: PropTypes.func
};